The purpose of the logbook_buoy_owner_control function is to provide a table of data that contains a incoherent buoy whose owner is missing

logbook_buoy_owner_control(dataframe1, output)

Arguments

dataframe1

data.frame expected. Csv or output of the function data_extraction, which must be done before using the logbook_buoy_owner_control.

output

character expected. Kind of expected output. You can choose between "message", "report" or "logical".

Value

The function returns a character with output is "message", a data.frame with output is "report", a logical with output is "logical".

Details

The input dataframe must contain all these columns for the function to work :

  • transmittingbuoy_id

  • transmittingbuoyownership_id

Examples

#Buoy 1 is ok,
#Buoy 2 has owner missing
dataframe1 <- data.frame(transmittingbuoy_id = c("1", "2"),
                         transmittingbuoyownership_id = c("1", NA))
logbook_buoy_owner_control(dataframe1, output = "report")
#>   transmittingbuoy_id logical
#> 1                   1    TRUE
#> 2                   2   FALSE