R/logbook_buoy_owner_control.R
logbook_buoy_owner_control.RdThe purpose of the logbook_buoy_owner_control function is to provide a table of data that contains a incoherent buoy whose owner is missing
logbook_buoy_owner_control(dataframe1, output)data.frame expected. Csv or output of the function data_extraction, which must be done before using the logbook_buoy_owner_control.
character expected. Kind of expected output. You can choose between "message", "report" or "logical".
The function returns a character with output is "message", a data.frame with output is "report", a logical with output is "logical".
The input dataframe must contain all these columns for the function to work :
transmittingbuoy_id
transmittingbuoyownership_id
#Buoy 1 is ok,
#Buoy 2 has owner missing
dataframe1 <- data.frame(transmittingbuoy_id = c("1", "2"),
transmittingbuoyownership_id = c("1", NA))
logbook_buoy_owner_control(dataframe1, output = "report")
#> transmittingbuoy_id logical
#> 1 1 TRUE
#> 2 2 FALSE