R/logbook_floating_object_part_material_control.R
logbook_floating_object_part_material_control.RdThe purpose of the logbook_floating_object_part_material_control function is to provide a table of data that contains a incoherent floating object material. Indeed, certain floating objects are not used in check fishing.
logbook_floating_object_part_material_control(
dataframe1,
dataframe2,
output,
object_material = c("1-2")
)data.frame expected. Csv or output of the function data_extraction, which must be done before using the logbook_floating_object_part_material_control.
data.frame expected. Csv or output of the function data_extraction, which must be done before using the logbook_floating_object_part_material_control.
character expected. Kind of expected output. You can choose between "message", "report" or "logical".
character expected. Default values: c("1-2"). Vector containing the codes for materials that are not traditionally used on a floating object.
The function returns a character with output is "message", a data.frame with output is "report", a logical with output is "logical".
The input dataframe must contain all these columns for the function to work :
floatingobject_id
Dataframe 2:
floatingobjectpart_id
objectmaterial_code
floatingobject_id
#Floating object 1 is ok,
#Floating object 2 has object material not used in the fishing.
dataframe1 <- data.frame(floatingobject_id = c("1", "2"))
dataframe2 <- data.frame(floatingobjectpart_id = c("1", "2"),
objectmaterial_code = c("1-1", "1-2"),
floatingobject_id = c("1", "2"))
logbook_floating_object_part_material_control(dataframe1, dataframe2, output = "report")
#> floatingobject_id logical
#> 1 1 TRUE
#> 2 2 FALSE